
# 价值投资
> 一般而言，趋势跟踪策略更适合底层具体标的的交易操作，而轮动策略更适合顶层配置。例如，在多品种多周期复合趋势跟踪策略中，交易具体每个品种的策略是时间序列模型，但顶层资金如何动态分配到各个品种，一般是用轮动策略。

# 趋势跟踪
做多、做空
## 信息传播过程
资产价格就会在信息传播的整个过程中出现一个单边上涨（利好消息逐步扩散）或单边下跌（利空消息逐步扩散）的趋势。
## 经济或产业的固有周期
投资标的所处的行业大多具有一定的周期性，这种周期结构一般是由供需力量的强弱交替变化导致的，在经济上具有一定的惯性。
## 投资者情绪的推动
投资者的恐惧和兴奋情绪往往会加剧趋势的波动幅度，理性投资者就可以利用其他投资者的过激反应来借势盈利。当然，在这个过程中你要时刻保持清醒，从标的的上涨幅度走势、交易量走势中去验证其他投资者的情绪是否高涨，一旦发现减弱的趋势，就应该及早结束这次投资。

# 轮动策略




分享几个带源码的策略，帮助大家学习
价值选股：https://www.joinquant.com/view/community/detail/713a60a2a1daaac2276dab73eb322ddc?type=1
海龟交易：https://www.joinquant.com/view/community/detail/4c13f3474a2164f7ea4620105c479c73?type=1
2020优秀文章：https://www.joinquant.com/view/community/detail/e83e772fa0c3292b418a3e43e7eb737e?type=1
